v1.0.4
=======
- fixed bug that was confusing snapshot with archive when archive function was called on the ResearchObject
- :func:`rohub.resource_assign_doi` and :func:`Resource.assign_doi` modified and now got new optional argument - external_doi
- added functions
    * :func:`rohub.resource_set_license`
    * :func:`rohub.resource_list_license`
    * :func:`resource_delete_license`
    * :func:`Resource.set_license`
    * :func:`Resource.list_license`
    * :func:`Resource.delete_license`